pub struct WolfSoundVariant {
pub key: Identifier,
pub adult_sounds: WolfAge,
pub baby_sounds: WolfAge,
}Expand description
Represents a set of sounds for a wolf variant from a data pack JSON file.
Fields
key: Identifieradult_sounds: WolfAgebaby_sounds: WolfAgeTrait Implementations
Sourceimpl Debug for WolfSoundVariant
impl Debug for WolfSoundVariant
impl Eq for WolfSoundVariant
Sourceimpl PartialEq for WolfSoundVariant
impl PartialEq for WolfSoundVariant
Sourceimpl RegistryEntry for WolfSoundVariant
impl RegistryEntry for WolfSoundVariant
Sourceimpl RegistryReferenceEntry for WolfSoundVariant
impl RegistryReferenceEntry for WolfSoundVariant
Sourceconst REGISTRY_NAME: &'static str = "wolf sound variant"
const REGISTRY_NAME: &'static str = "wolf sound variant"
Human-readable registry name used in codec errors.
Sourcefn reference_by_id(id: usize) -> Option<&'static Self>
fn reference_by_id(id: usize) -> Option<&'static Self>
Looks up an entry by its protocol registry ID.
Sourcefn reference_by_key(key: &Identifier) -> Option<&'static Self>
fn reference_by_key(key: &Identifier) -> Option<&'static Self>
Looks up an entry by its registry key.
Sourceimpl ToNbtTag for &WolfSoundVariant
impl ToNbtTag for &WolfSoundVariant
fn to_nbt_tag(self) -> NbtTag
fn to_optional_nbt_tag(self) -> Option<NbtTag>